@@ -3,9 +3,11 @@ use warnings;
 
 package File::Util::Interface::Classic;
 {
-  $File::Util::Interface::Classic::VERSION = '4.130420'; # TRIAL
+  $File::Util::Interface::Classic::VERSION = '4.130425'; # TRIAL
 }
 
+# ABSTRACT: Legacy call interface to File::Util
+
 use Scalar::Util qw( blessed );
 
 use lib 'lib';
@@ -126,11 +128,11 @@ __END__
 
 =head1 NAME
 
-File::Util::Interface::Classic
+File::Util::Interface::Classic - Legacy call interface to File::Util
 
 =head1 VERSION
 
-version 4.130420
+version 4.130425
 
 =head1 DESCRIPTION
 
